summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/modules/m_alias.cpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/modules/m_alias.cpp b/src/modules/m_alias.cpp
index f73fd74db..db3d75bae 100644
--- a/src/modules/m_alias.cpp
+++ b/src/modules/m_alias.cpp
@@ -92,8 +92,11 @@ class ModuleAlias : public Module
userrec *u = NULL;
irc::string c = command.c_str();
- /* If the command is valid, we dont want to know */
- if (validated)
+ /* If the command is valid, we dont want to know,
+ * and if theyre not registered yet, we dont want
+ * to know either
+ */
+ if ((validated) || (user->registered != 7))
return 0;
for (unsigned int i = 0; i < Aliases.size(); i++)